summaryrefslogtreecommitdiffstats
path: root/admin
diff options
context:
space:
mode:
Diffstat (limited to 'admin')
-rw-r--r--admin/kde.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/admin/kde.py b/admin/kde.py
index c36fc64..49eb1a3 100644
--- a/admin/kde.py
+++ b/admin/kde.py
@@ -52,7 +52,7 @@ def exists(env):
return True
def detect_kde(env):
""" Detect the qt and kde environment using kde-config mostly """
def getpath(varname):
if not env.has_key('ARGS'): return None
v=env['ARGS'].get(varname, None)
@@ -82,15 +82,15 @@ def detect_kde(env):
if libdir: libdir = libdir+libsuffix
## Detect the kde libraries
- print "Checking for kde-config : ",
- str="which kde-config 2>/dev/null"
- if tdedir: str="which %s 2>/dev/null" % (tdedir+'/bin/kde-config')
+ print "Checking for tde-config : ",
+ str="which tde-config 2>/dev/null"
+ if tdedir: str="which %s 2>/dev/null" % (tdedir+'/bin/tde-config')
kde_config = os.popen(str).read().strip()
if len(kde_config):
- p('GREEN', 'kde-config was found as '+kde_config)
+ p('GREEN', 'tde-config was found as '+kde_config)
else:
- if tdedir: p('RED','kde-config was NOT found in the folder given '+tdedir)
- else: p('RED','kde-config was NOT found in your PATH')
+ if tdedir: p('RED','tde-config was NOT found in the folder given '+tdedir)
+ else: p('RED','tde-config was NOT found in your PATH')
print "Make sure kde is installed properly"
print "(missing package tdebase-devel?)"
env.Exit(1)
@@ -197,7 +197,7 @@ def detect_kde(env):
p('RED',"The kde includes were NOT found")
env.Exit(1)
- # kde-config options
+ # tde-config options
kdec_opts = {'KDEBIN' : 'exe', 'KDEAPPS' : 'apps',
'KDEDATA' : 'data', 'KDEICONS' : 'icon',
'KDEMODULE' : 'module', 'KDELOCALE' : 'locale',
@@ -52,7 +52,7 @@ def exists(env):
return True
def detect_kde(env):
- """ Detect the qt and kde environment using kde-config mostly """
+ """ Detect the qt and kde environment using tde-config mostly """
def getpath(varname):
if not env.has_key('ARGS'): return None